@@ -11,6 +11,10 @@ def create(microprotocol):
         from fdrtd.plugins.simon.microprotocols.microprotocol_secure_sum import MicroprotocolSecureSum
         return MicroprotocolSecureSum
 
+    if microprotocol == 'SecureMatrixMultiplication':
+        from fdrtd.plugins.simon.microprotocols.microprotocol_secure_matrix_multiplication import MicroprotocolSecureMatrixMultiplication
+        return MicroprotocolSecureMatrixMultiplication
+
     if microprotocol == 'SetIntersection':
         from fdrtd.plugins.simon.microprotocols.microprotocol_set_intersection import MicroprotocolSetIntersection
         return MicroprotocolSetIntersection
@@ -35,4 +39,12 @@ def create(microprotocol):
         from fdrtd.plugins.simon.microprotocols.microprotocol_statistics_univariate import MicroprotocolStatisticsUnivariate
         return MicroprotocolStatisticsUnivariate
 
+    if microprotocol == 'StatisticsContingencyVertical':
+        from fdrtd.plugins.simon.microprotocols.microprotocol_statistics_contingency_vertical import MicroprotocolStatisticsContingencyVertical
+        return MicroprotocolStatisticsContingencyVertical
+
+    if microprotocol == 'StatisticsRegressionOLSVertical':
+        from fdrtd.plugins.simon.microprotocols.microprotocol_statistics_regression_ols_vertical import MicroprotocolStatisticsRegressionOLSVertical
+        return MicroprotocolStatisticsRegressionOLSVertical
+
     raise fdrtd.server.exceptions.NotAvailable(microprotocol)
